import { Actions, PolicyStatement, ResourceTypes } from "./shared";
import { PolicyStatementProps } from "@aws-cdk/aws-iam";
/**
 * Action provider for service codeguru-reviewer
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodegurureviewer.html
 */
export declare class CodeguruReviewer extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    resourceTypes: ResourceTypes;
    /**
     * Action provider for service codeguru-reviewer
     *
     * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodegurureviewer.html
     */
    constructor(props?: PolicyStatementProps);
    /**
     * Grants permission to associates a repository with Amazon CodeGuru Reviewer.
     *
     * Access Level: Write
     */
    associateRepository(): this;
    /**
     * Grants permission to perform webbased oauth handshake for 3rd party providers.
     *
     * Access Level: Read
     */
    createConnectionToken(): this;
    /**
     * Grants permission to describe a code review.
     *
     * Access Level: Read
     */
    describeCodeReview(): this;
    /**
     * Grants permission to describe a recommendation feedback on a code review.
     *
     * Access Level: Read
     */
    describeRecommendationFeedback(): this;
    /**
     * Grants permission to describe a repository association.
     *
     * Access Level: Read
     */
    describeRepositoryAssociation(): this;
    /**
     * Grants permission to disassociate a repository with Amazon CodeGuru Reviewer.
     *
     * Access Level: Write
     */
    disassociateRepository(): this;
    /**
     * Grants permission to view pull request metrics in console.
     *
     * Access Level: Read
     */
    getMetricsData(): this;
    /**
     * Grants permission to list summary of code reviews.
     *
     * Access Level: List
     */
    listCodeReviews(): this;
    /**
     * Grants permission to list summary of recommendation feedback on a code review.
     *
     * Access Level: List
     */
    listRecommendationFeedback(): this;
    /**
     * Grants permission to list summary of recommendations on a code review
     *
     * Access Level: List
     */
    listRecommendations(): this;
    /**
     * Grants permission to list summary of repository associations.
     *
     * Access Level: List
     */
    listRepositoryAssociations(): this;
    /**
     * Grants permission to list 3rd party providers repositories in console.
     *
     * Access Level: Read
     */
    listThirdPartyRepositories(): this;
    /**
     * Grants permission to put feedback for a recommendation on a code review.
     *
     * Access Level: Write
     */
    putRecommendationFeedback(): this;
    /**
     * Adds a resource of type association to the statement
     *
     * @param resourceId - Identifier for the resourceId.
     * @param account - Account of the resource; defaults to empty string: all accounts.
     * @param region - Region of the resource; defaults to empty string: all regions.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`.
     */
    onAssociation(resourceId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Adds a resource of type codereview to the statement
     *
     * @param codeReviewUuid - Identifier for the codeReviewUuid.
     * @param account - Account of the resource; defaults to empty string: all accounts.
     * @param region - Region of the resource; defaults to empty string: all regions.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`.
     */
    onCodereview(codeReviewUuid: string, account?: string, region?: string, partition?: string): this;
    /**
     * Adds a resource of type repository to the statement
     *
     * https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/auth-and-access-control-iam-access-control-identity-based.html#arn-formats
     *
     * @param repositoryName - Identifier for the repositoryName.
     * @param account - Account of the resource; defaults to empty string: all accounts.
     * @param region - Region of the resource; defaults to empty string: all regions.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`.
     *
     * Possible condition keys:
     *  - aws:ResourceTag/${TagKey}
     */
    onRepository(repositoryName: string, account?: string, region?: string, partition?: string): this;
}
