import { Actions, PolicyStatement, ResourceTypes } from "./shared";
import { PolicyStatementProps } from "@aws-cdk/aws-iam";
/**
 * Action provider for service elastic-inference
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticinference.html
 */
export declare class ElasticInference extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    resourceTypes: ResourceTypes;
    /**
     * Action provider for service elastic-inference
     *
     * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticinference.html
     */
    constructor(props?: PolicyStatementProps);
    /**
     * Connects customer to Elastic Inference accelerator
     *
     * Access Level: Write
     */
    connect(): this;
    /**
     * Adds a resource of type accelerator to the statement
     *
     * @param acceleratorId - Identifier for the acceleratorId.
     * @param account - Account of the resource; defaults to empty string: all accounts.
     * @param region - Region of the resource; defaults to empty string: all regions.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`.
     */
    onAccelerator(acceleratorId: string, account?: string, region?: string, partition?: string): this;
}
