import { Actions, PolicyStatement, ResourceTypes } from "./shared";
import { PolicyStatementProps } from "@aws-cdk/aws-iam";
/**
 * Action provider for service applicationinsights
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_cloudwatchapplicationinsights.html
 */
export declare class Applicationinsights extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    resourceTypes: ResourceTypes;
    /**
     * Action provider for service applicationinsights
     *
     * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_cloudwatchapplicationinsights.html
     */
    constructor(props?: PolicyStatementProps);
    /**
     * Creates an application from a resource group
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_CreateApplication.html
     */
    createApplication(): this;
    /**
     * Creates a component from a group of resources
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_CreateComponent.html
     */
    createComponent(): this;
    /**
     * Deletes an application
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DeleteApplication.html
     */
    deleteApplication(): this;
    /**
     * Deletes a component
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DeleteComponent.html
     */
    deleteComponent(): this;
    /**
     * Describes an application
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeApplication.html
     */
    describeApplication(): this;
    /**
     * Describes a component
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeComponent.html
     */
    describeComponent(): this;
    /**
     * Describes a component configuration
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeComponentConfiguration.html
     */
    describeComponentConfiguration(): this;
    /**
     * Describe the recommended application component configuration
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeComponentConfigurationRecommendation.html
     */
    describeComponentConfigurationRecommendation(): this;
    /**
     * Describes an observation
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeObservation.html
     */
    describeObservation(): this;
    /**
     * Describes a problem
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeProblem.html
     */
    describeProblem(): this;
    /**
     * Describes the observation in a problem
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_DescribeProblemObservations.html
     */
    describeProblemObservations(): this;
    /**
     * Lists all applications
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_ListApplications.html
     */
    listApplications(): this;
    /**
     * List an application's components
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_ListComponents.html
     */
    listComponents(): this;
    /**
     * Lists the problems in an application
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_ListProblems.html
     */
    listProblems(): this;
    /**
     * Updates an application
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_UpdateApplication.html
     */
    updateApplication(): this;
    /**
     * Updates a component
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_UpdateComponent.html
     */
    updateComponent(): this;
    /**
     * Updates a component configuration
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/appinsights/1.0/APIReference/API_UpdateComponentConfiguration.html
     */
    updateComponentConfiguration(): this;
}
